@@ -293,19 +293,25 @@ def _ensure_app_icon(android_dir: Path) -> None:
     """Copy appIcon.png and splash screen from config locations and generate Android resources."""
     print("🔍 Looking for app icon and splash screen...")
     
-    # Look for appIcon.png in known config locations
+    # Look for appIcon - prioritize SVG vectors for perfect quality!
     icon_candidates = [
         os.environ.get("AIROBO_APP_ICON_PATH"),
+        r"C:\airoboConfigs\appIcon.svg",     # 🎯 SVG FIRST for vector quality!
         r"C:\airoboConfigs\appIcon.png",
+        r"C:\airobo\appIcon.svg",
         r"C:\airobo\appIcon.png",
+        os.path.expanduser("~/airoboConfigs/appIcon.svg"),
         os.path.expanduser("~/airoboConfigs/appIcon.png"),
     ]
     
-    # Look for splash screen in same locations
+    # Look for splash screen - prioritize SVG vectors!
     splash_candidates = [
         os.environ.get("AIROBO_SPLASH_PATH"),
+        r"C:\airoboConfigs\splash.svg",      # 🎯 SVG FIRST for vector quality!
         r"C:\airoboConfigs\splash.png",
+        r"C:\airobo\splash.svg",
         r"C:\airobo\splash.png",
+        os.path.expanduser("~/airoboConfigs/splash.svg"),
         os.path.expanduser("~/airoboConfigs/splash.png"),
     ]
     
@@ -347,13 +353,13 @@ def _ensure_app_icon(android_dir: Path) -> None:
     app_cache_root = android_dir.parent
     web_public_dir = app_cache_root / "public"
     
-    # Android mipmap density folders and target sizes - HIGHER RES for better quality
+    # Android mipmap density folders and target sizes - ULTRA HIGH RES for perfect quality
     densities = {
-        "mipmap-mdpi": 64,      # Was 48, now higher base
-        "mipmap-hdpi": 96,      # Was 72 
-        "mipmap-xhdpi": 128,    # Was 96
-        "mipmap-xxhdpi": 192,   # Was 144
-        "mipmap-xxxhdpi": 256,  # Was 192 - this is what most modern phones use!
+        "mipmap-mdpi": 96,       # Was 64, now 2x higher
+        "mipmap-hdpi": 144,      # Was 96, now 2x higher
+        "mipmap-xhdpi": 192,     # Was 128, now 2x higher  
+        "mipmap-xxhdpi": 288,    # Was 192, now 2x higher
+        "mipmap-xxxhdpi": 384,   # Was 256, now 2x higher - ULTRA crisp!
     }
     
     res_dir = android_dir / "app" / "src" / "main" / "res"
@@ -364,14 +370,55 @@ def _ensure_app_icon(android_dir: Path) -> None:
         from PIL import Image
         print("📦 Pillow loaded successfully")
         
-        # Load source image
-        with Image.open(source_icon) as img:
-            print(f"🖼️ Source image: {img.size[0]}x{img.size[1]} pixels, mode: {img.mode}")
-            
-            # Convert to RGBA if needed for transparency support
-            if img.mode != 'RGBA':
-                img = img.convert('RGBA')
-                print("🔄 Converted to RGBA mode")
+        # Check if we need to handle SVG files
+        is_svg_icon = source_icon and source_icon.suffix.lower() == '.svg'
+        is_svg_splash = source_splash and source_splash.suffix.lower() == '.svg'
+        
+        if is_svg_icon or is_svg_splash:
+            try:
+                import cairosvg
+                print("🎨 CairoSVG loaded for vector processing")
+            except ImportError:
+                print("⚠️ CairoSVG not installed. Installing for SVG processing...")
+                import subprocess
+                subprocess.run([
+                    "pip", "install", "cairosvg"
+                ], check=True, capture_output=True)
+                import cairosvg
+                print("✅ CairoSVG installed successfully")
+        
+        def load_icon_at_size(size):
+            """Load icon at specified size, handling both PNG and SVG"""
+            if is_svg_icon:
+                # Convert SVG to PNG at exact size for perfect quality
+                import io
+                png_data = cairosvg.svg2png(
+                    url=str(source_icon), 
+                    output_width=size, 
+                    output_height=size
+                )
+                return Image.open(io.BytesIO(png_data))
+            else:
+                # Load PNG and resize
+                with Image.open(source_icon) as img:
+                    # Convert to RGBA if needed
+                    if img.mode != 'RGBA':
+                        img = img.convert('RGBA')
+                    return img.resize((size, size), Image.Resampling.LANCZOS)
+        
+        # Load source image for initial processing
+        if is_svg_icon:
+            # For SVG, load at a reasonable preview size
+            with load_icon_at_size(512) as img:
+                print(f"🎨 Vector icon loaded: {img.size[0]}x{img.size[1]} pixels (from SVG)")
+        else:
+            with Image.open(source_icon) as img:
+                print(f"🖼️ Source image: {img.size[0]}x{img.size[1]} pixels, mode: {img.mode}")
+                
+                # Convert to RGBA if needed for transparency support
+                if img.mode != 'RGBA':
+                    img = img.convert('RGBA')
+                    print("🔄 Converted to RGBA mode")
             
             # FIRST: Replace web icons that Capacitor might use as source
             web_icons_updated = 0
@@ -417,11 +464,9 @@ def _ensure_app_icon(android_dir: Path) -> None:
                 # The visible area is ~72dp, but we need 108dp for the full adaptive icon
                 adaptive_size = int(size * 1.5)  # 1.5x for 108dp vs 72dp
                 
-                # Create standard size for regular icons
-                resized = img.resize((size, size), Image.Resampling.LANCZOS)
-                
-                # Create larger size for adaptive foreground (better quality)
-                adaptive_resized = img.resize((adaptive_size, adaptive_size), Image.Resampling.LANCZOS)
+                # 🎯 VECTOR QUALITY: Load icon at exact target size
+                resized = load_icon_at_size(size)
+                adaptive_resized = load_icon_at_size(adaptive_size)
                 
                 # Regular launcher icons
                 output_path = density_dir / "ic_launcher.png"
@@ -438,85 +483,143 @@ def _ensure_app_icon(android_dir: Path) -> None:
                 print(f"   📱 {density}: {size}x{size} -> {output_path}")
                 print(f"      + foreground: {adaptive_size}x{adaptive_size} -> {foreground_output}")
                 icons_created += 3  # launcher + round + foreground
+                
+                # Close images to free memory
+                resized.close()
+                adaptive_resized.close()
             
             # SPLASH SCREENS: Replace all splash screens if splash image is provided
             if source_splash:
-                print("🎨 Updating splash screens with proper densities...")
+                print(f"🎨 Updating splash screens with proper densities...")
+                print(f"   🎨 Processing {'SVG vector' if is_svg_splash else 'PNG raster'} splash...")
                 splash_files_updated = 0
                 
-                # Load splash image
-                with Image.open(source_splash) as splash_img:
-                    print(f"   📏 Source splash: {splash_img.size[0]}x{splash_img.size[1]}")
+                def load_splash_at_size(width, height):
+                    """Load splash at specified size, handling both PNG and SVG"""
+                    if is_svg_splash:
+                        # Convert SVG to PNG at exact size for perfect quality
+                        import io
+                        png_data = cairosvg.svg2png(
+                            url=str(source_splash), 
+                            output_width=width, 
+                            output_height=height
+                        )
+                        return Image.open(io.BytesIO(png_data))
+                    else:
+                        # Load PNG and resize
+                        with Image.open(source_splash) as splash_img:
+                            return splash_img.resize((width, height), Image.Resampling.LANCZOS)
+                
+                # Get source dimensions for logging
+                if is_svg_splash:
+                    print(f"   📏 Vector splash: scalable SVG")
+                else:
+                    with Image.open(source_splash) as splash_img:
+                        print(f"   📏 Source splash: {splash_img.size[0]}x{splash_img.size[1]}")
+                
+                # FIRST: Create main splash drawable in drawable folder (not density-specific)
+                main_drawable_dir = res_dir / "drawable"
+                main_drawable_dir.mkdir(parents=True, exist_ok=True)
+                main_splash_path = main_drawable_dir / "splash.png"
+                
+                # Create high-quality main splash
+                main_splash = load_splash_at_size(1080, 1920)  # Standard FHD resolution
+                main_splash.save(main_splash_path, "PNG", optimize=False, compress_level=1)
+                print(f"   🎯 Main splash: 1080x1920 -> {main_splash_path}")
+                main_splash.close()
+                splash_files_updated += 1
+                
+                # Standard splash screen sizes for different densities
+                splash_densities = {
+                    "drawable-mdpi": (320, 480),       # ~160dpi
+                    "drawable-hdpi": (480, 720),       # ~240dpi  
+                    "drawable-xhdpi": (720, 1280),     # ~320dpi
+                    "drawable-xxhdpi": (1080, 1920),   # ~480dpi - most common
+                    "drawable-xxxhdpi": (1440, 2560),  # ~640dpi - highest res
+                }
+                
+                # Also handle landscape orientations
+                splash_densities_land = {
+                    "drawable-land-mdpi": (480, 320),
+                    "drawable-land-hdpi": (720, 480),
+                    "drawable-land-xhdpi": (1280, 720),
+                    "drawable-land-xxhdpi": (1920, 1080),
+                    "drawable-land-xxxhdpi": (2560, 1440),
+                }
+                
+                # Combine both orientations
+                all_splash_densities = {**splash_densities, **splash_densities_land}
+                
+                # Generate splash screens for each density
+                for density_name, (width, height) in all_splash_densities.items():
+                    density_dir = res_dir / density_name
+                    density_dir.mkdir(parents=True, exist_ok=True)
                     
-                    # Standard splash screen sizes for different densities
-                    splash_densities = {
-                        "drawable-mdpi": (320, 480),       # ~160dpi
-                        "drawable-hdpi": (480, 720),       # ~240dpi  
-                        "drawable-xhdpi": (720, 1280),     # ~320dpi
-                        "drawable-xxhdpi": (1080, 1920),   # ~480dpi - most common
-                        "drawable-xxxhdpi": (1440, 2560),  # ~640dpi - highest res
-                    }
+                    # 🎯 VECTOR QUALITY: Load splash at exact target size
+                    splash_resized = load_splash_at_size(width, height)
                     
-                    # Also handle landscape orientations
-                    splash_densities_land = {
-                        "drawable-land-mdpi": (480, 320),
-                        "drawable-land-hdpi": (720, 480),
-                        "drawable-land-xhdpi": (1280, 720),
-                        "drawable-land-xxhdpi": (1920, 1080),
-                        "drawable-land-xxxhdpi": (2560, 1440),
-                    }
+                    splash_output = density_dir / "splash.png"
+                    splash_resized.save(splash_output, "PNG", optimize=False, compress_level=1)
+                    print(f"   🖼️ {density_name}: {width}x{height} -> {splash_output}")
+                    splash_files_updated += 1
                     
-                    # Combine both orientations
-                    all_splash_densities = {**splash_densities, **splash_densities_land}
-                    
-                    # Generate splash screens for each density
-                    for density_name, (width, height) in all_splash_densities.items():
-                        density_dir = res_dir / density_name
-                        density_dir.mkdir(parents=True, exist_ok=True)
+                    # Close image to free memory
+                    splash_resized.close()
+                
+                # Also find and replace any existing splash files with our custom one
+                for splash_file in res_dir.rglob("*splash*"):
+                    if splash_file.is_file() and splash_file.suffix.lower() in ('.png', '.jpg', '.jpeg'):
+                        if splash_file.parent.name not in all_splash_densities:
+                            # This is an existing splash file, replace it with our custom splash
+                            default_splash = load_splash_at_size(1080, 1920)
+                            default_splash.save(splash_file, "PNG", optimize=False, compress_level=1)
+                            print(f"   🔄 Replaced existing: {splash_file.relative_to(res_dir)}")
+                            splash_files_updated += 1
+                            default_splash.close()
+                
+                # CRITICAL: Update styles.xml to ensure splash screen uses our image, not app icon
+                styles_file = res_dir / "values" / "styles.xml"
+                if styles_file.exists():
+                    print("🎨 Updating styles.xml to prevent app icon fallback...")
+                    try:
+                        styles_content = styles_file.read_text(encoding='utf-8')
                         
-                        # Resize maintaining aspect ratio, center on colored background
-                        splash_resized = splash_img.resize((width, height), Image.Resampling.LANCZOS)
+                        # Replace the problematic Theme.SplashScreen with a custom theme that doesn't use app icon
+                        updated_styles = styles_content.replace(
+                            'parent="Theme.SplashScreen"', 'parent="Theme.AppCompat.Light.NoActionBar"'
+                        ).replace(
+                            '@mipmap/ic_launcher', '@drawable/splash'
+                        ).replace(
+                            '@mipmap/ic_launcher_foreground', '@drawable/splash'  
+                        ).replace(
+                        )
                         
-                        splash_output = density_dir / "splash.png"
-                        splash_resized.save(splash_output, "PNG", optimize=False, compress_level=1)
-                        print(f"   🖼️ {density_name}: {width}x{height} -> {splash_output}")
-                        splash_files_updated += 1
-                    
-                    # Also find and replace any existing splash files with our custom one
-                    for splash_file in res_dir.rglob("*splash*"):
-                        if splash_file.is_file() and splash_file.suffix.lower() in ('.png', '.jpg', '.jpeg'):
-                            if splash_file.parent.name not in all_splash_densities:
-                                # This is an existing splash file, replace it with our custom splash
-                                default_splash = splash_img.resize((1080, 1920), Image.Resampling.LANCZOS)
-                                default_splash.save(splash_file, "PNG", optimize=False, compress_level=1)
-                                print(f"   🔄 Replaced existing: {splash_file.relative_to(res_dir)}")
-                                splash_files_updated += 1
-                    
-                    # CRITICAL: Update styles.xml to ensure splash screen uses our image, not app icon
-                    styles_file = res_dir / "values" / "styles.xml"
-                    if styles_file.exists():
-                        print("🎨 Updating styles.xml to prevent app icon fallback...")
-                        try:
-                            styles_content = styles_file.read_text(encoding='utf-8')
+                        # Also ensure we have proper splash screen styling that prevents icon usage
+                        if 'AppTheme.NoActionBarLaunch' in updated_styles:
+                            # Add window splash screen properties to override Android 12+ behavior
+                            splash_theme_section = '''<style name="AppTheme.NoActionBarLaunch" parent="Theme.AppCompat.Light.NoActionBar">
+        <item name="android:background">@drawable/splash</item>
+        <item name="android:windowSplashScreenBackground">@drawable/splash</item>
+        <item name="android:windowSplashScreenAnimatedIcon">@drawable/splash</item>
+        <item name="android:windowSplashScreenIconBackgroundColor">@android:color/transparent</item>
+        <item name="windowActionBar">false</item>
+        <item name="windowNoTitle">true</item>
+    </style>'''
                             
-                            # Replace any references to app icon in splash screen styles
-                            # Look for windowSplashscreenContent that might reference the app icon
-                            updated_styles = styles_content.replace(
-                                '@mipmap/ic_launcher', '@drawable/splash'
-                            ).replace(
-                                '@mipmap/ic_launcher_foreground', '@drawable/splash'  
-                            ).replace(
-                                'ic_launcher', 'splash'
-                            )
+                            # Replace the existing splash theme
+                            import re
+                            pattern = r'<style name="AppTheme\.NoActionBarLaunch".*?</style>'
+                            updated_styles = re.sub(pattern, splash_theme_section, updated_styles, flags=re.DOTALL)
+                        
+                        if updated_styles != styles_content:
+                            styles_file.write_text(updated_styles, encoding='utf-8')
+                            print("   ✅ Updated styles.xml to use splash drawable instead of app icon")
+                            print("   🎯 Disabled Android 12+ splash screen API that forces app icon usage")
+                        else:
+                            print("   ℹ️ styles.xml already configured correctly")
                             
-                            if updated_styles != styles_content:
-                                styles_file.write_text(updated_styles, encoding='utf-8')
-                                print("   ✅ Updated styles.xml to use splash drawable instead of app icon")
-                            else:
-                                print("   ℹ️ styles.xml already configured correctly")
-                                
-                        except Exception as e:
-                            print(f"   ⚠️ Could not update styles.xml: {e}")
+                    except Exception as e:
+                        print(f"   ⚠️ Could not update styles.xml: {e}")
                 
                 print(f"🎨 Generated {splash_files_updated} splash screen files across multiple densities")
                 print("🎯 Splash screen should now display your custom image, not the app icon")
